@@ -59,7 +59,6 @@ import jcifs.smb.SmbException;
 import jcifs.smb.SmbFile;
 import jcifs.smb.SmbFileFilter;
 import org.apache.commons.httpclient.URI;
-import org.apache.commons.logging.Log;
 import com.openexchange.exception.OXException;
 import com.openexchange.file.storage.FileStorageAccount;
 import com.openexchange.file.storage.FileStorageExceptionCodes;
@@ -79,8 +78,7 @@ import com.openexchange.session.Session;
  */
 public final class CIFSFolderAccess extends AbstractCIFSAccess implements FileStorageFolderAccess {
 
-    private static final Log LOG = com.openexchange.log.Log.loggerFor(CIFSFolderAccess.class);
-    private static final boolean DEBUG = LOG.isDebugEnabled();
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(CIFSFolderAccess.class);
 
     /**
      * Constant string to indicate that home directory has not been found.
@@ -241,7 +239,6 @@ public final class CIFSFolderAccess extends AbstractCIFSAccess implements FileSt
                     /*
                      * Try to determine home directory by user name
                      */
-                    final long st = DEBUG ? System.currentTimeMillis() : 0L;
                     try {
                         final String folderId = rootUrl;
                         final String fid = checkFolderId(folderId, rootUrl);
@@ -269,10 +266,6 @@ public final class CIFSFolderAccess extends AbstractCIFSAccess implements FileSt
                     } catch (final RuntimeException e) {
                         homeDirPath = NOT_FOUND;
                     }
-                    if (DEBUG) {
-                        final long dur = System.currentTimeMillis() - st;
-                        LOG.debug("CIFSFolderAccess.getHomeDirectory() took " + dur + "msec.");
-                    }
                     this.homeDirPath = homeDirPath;
                 }
             }
@@ -425,14 +418,7 @@ public final class CIFSFolderAccess extends AbstractCIFSAccess implements FileSt
              */
             SmbFile[] subFiles;
             try {
-                if (DEBUG) {
-                    final long st = System.currentTimeMillis();
-                    subFiles = smbFolder.canRead() ? smbFolder.listFiles(DICTIONARY_FILTER) : new SmbFile[0];
-                    final long dur = System.currentTimeMillis() - st;
-                    LOG.debug("CIFSFolderAccess.getSubfolders() - SmbFile.listFiles() took " + dur + "msec.");
-                } else {
-                    subFiles = smbFolder.canRead() ? smbFolder.listFiles(DICTIONARY_FILTER) : new SmbFile[0];
-                }
+                subFiles = smbFolder.canRead() ? smbFolder.listFiles(DICTIONARY_FILTER) : new SmbFile[0];
             } catch (final SmbException e) {
                 if (!indicatesNotReadable(e)) {
                     throw e;
@@ -528,6 +514,11 @@ public final class CIFSFolderAccess extends AbstractCIFSAccess implements FileSt
 
     @Override
     public String moveFolder(final String folderId, final String newParentId) throws OXException {
+        return moveFolder(folderId, newParentId, null);
+    }
+
+    @Override
+    public String moveFolder(final String folderId, final String newParentId, String newName) throws OXException {
         try {
             final String fid = checkFolderId(folderId, rootUrl);
             if (rootUrl.equalsIgnoreCase(fid)) {
@@ -551,7 +542,7 @@ public final class CIFSFolderAccess extends AbstractCIFSAccess implements FileSt
                 if (path.endsWith(SLASH)) {
                     path = path.substring(0, path.length() - 1);
                 }
-                uri.setPath(new StringBuilder(path).append('/').append(name).toString());
+                uri.setPath(new StringBuilder(path).append('/').append(null != newName ? newName : name).toString());
                 newUri = checkFolderId(uri.toString());
             }
             /*
